==> camunda-webapp-webjar-7.14.0.jar: META-INF/resources/webjars/camunda/app/admin/scripts/config.js <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

window.camAdminConf = {
  // // custom libraries and scripts loading and initialization,
  // // see: http://docs.camunda.org/guides/user-guide/#tasklist-customizing-custom-scripts
  // customScripts: {
  //   // AngularJS module names
  //   ngDeps: ['ui.bootstrap'],
  //   // RequireJS configuration for a complete configuration documentation see:
  //   // http://requirejs.org/docs/api.html#config
  //   deps: ['jquery', 'custom-ui'],
  //   paths: {
  //     // if you have a folder called `custom-ui` (in the `cockpit` folder)
  //     // with a file called `scripts.js` in it and defining the `custom-ui` AMD module
  //     'custom-ui': 'custom-ui/scripts'
  //   }
  // },
  // 'runtimeActivityInstanceMetrics': {
  //   'display': true
  // },
  // 'historicActivityInstanceMetrics': {
  //   'adjustablePeriod': true,
  //   'period': {
  //     'unit': 'day'
  //   }
  // },
  // 'locales': {
  //   'availableLocales': ['en', 'de'],
  //   'fallbackLocale': 'en'
  // },
  // csrfCookieName: 'XSRF-TOKEN',
  // disableWelcomeMessage: false,
  // userOperationLogAnnotationLength: 4000
};

==> camunda-webapp-webjar-7.18.0.jar: META-INF/resources/webjars/camunda/app/admin/scripts/config.js <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  // // change the app name and vendor
  // app: {
  //   name: 'Admin',
  //   vendor: 'Company'
  // },
  // // custom libraries and scripts loading and initialization,
  // // see: http://docs.camunda.org/guides/user-guide/#tasklist-customizing-custom-scripts
  // customScripts: [
  //   // If you have a folder called 'my-custom-script' (in the 'admin' folder)
  //   // with a file called 'customScript.js' in it
  //   // 'my-custom-script/customScript'
  // ],
  // requireJsConfig: {
  //   // AngularJS module names
  //   ngDeps: ['ui.bootstrap'],
  //   // RequireJS configuration for a complete configuration documentation see:
  //   // http://requirejs.org/docs/api.html#config
  //   deps: ['jquery', 'custom-ui'],
  //   paths: {
  //     // if you have a folder called `custom-ui` (in the `admin` folder)
  //     // with a file called `scripts.js` in it and defining the `custom-ui` AMD module
  //     'custom-ui': 'custom-ui/scripts'
  //   }
  // },
  // 'runtimeActivityInstanceMetrics': {
  //   'display': true
  // },
  // 'historicActivityInstanceMetrics': {
  //   'adjustablePeriod': true,
  //   'period': {
  //     'unit': 'day'
  //   }
  // },
  // 'alwaysShowUniqueTaskWorkerMetrics': true,
  // 'locales': {
  //   'availableLocales': ['en', 'de'],
  //   'fallbackLocale': 'en'
  // },
  // csrfCookieName: 'XSRF-TOKEN',
  // disableWelcomeMessage: false,
  // userOperationLogAnnotationLength: 4000
};
